##  Best Practices
Software deployment typically involves multiple environments, such as testing, staging, and production. Since SAP LeanIX focuses on enterprise architecture management, we recommend cataloging only services deployed to the production environment. This approach aligns with our goal of providing a comprehensive view of the software infrastructure to support strategic decision-making.
For technical use cases that need visibility across all environments, specialized tools are available in the market.
